@@ -204,6 +204,7 @@ lm.sdf <- function(formula,
                    standardizeWithSamplingVar=FALSE) {
   call <- match.call()
   checkDataClass(data, c("edsurvey.data.frame", "light.edsurvey.data.frame", "edsurvey.data.frame.list"))
+  weightVar <- iparse(substitute(weightVar), x=data)
   # if data is an edsurvey.data.frame.list, simply return a list with results
   # for each edsurvey.data.frame
   if (inherits(data, c("edsurvey.data.frame.list"))) {
@@ -272,15 +273,7 @@ calc.lm.sdf <- function(formula,
   }
   
   # if the weight var is not set, use the default
-  if(is.null(weightVar)) {
-    wgt <- attributes(getAttributes(sdf, "weights"))$default
-  } else {
-    wgt <- weightVar
-  } # End of if/else: is.null(weightVar)
-  if(min(nchar(wgt)) == 0) {
-    # no weight
-    stop(paste0("There is no default weight variable for ",getAttributes(sdf,"survey")," data, so the argument ",sQuote("weightVar"), " must be specified."))
-  }
+  wgt <- checkWeightVar(data, weightVar)
   # check if there is an outcome variable and set it to the default if it is missing
   zeroLengthLHS <- attr(terms(formula), "response") == 0
   if(zeroLengthLHS) {
