@@ -1,8 +1,8 @@
 \dontrun{
 # root argument will vary by operating system conventions
-downloadHSLS(root = "C:/", years=2009)
+downloadHSLS(root = "~/", years=2009)
 
 # set verbose=FALSE for silent output
 # if year not specified, download all years
-downloadHSLS(root="C:/", verbose = FALSE)
+downloadHSLS(root="~/", verbose = FALSE)
 }
