@@ -1,5 +1,5 @@
 \dontrun{
-eng <- readCivEDICCS("C:/ICCS2009/Gr8", countries = c("eng"),
+eng <- readCivEDICCS("~/ICCS/2009/", countries = c("eng"),
                      gradeLvl = 8, dataSet = "student")
 gg <- getData(eng, c("famstruc", "totwgts", "civ"))
 head(gg)
