@@ -24,30 +24,30 @@ test_that("ELS data reads in correctly",{
   expect_silent(els <<- readELS(file.path(edsurveyHome, "ELS", "2002"), filename = "els_02_12_byf3pststu_v1_0.sav", wgtFilename = "els_02_12_byf3stubrr_v1_0.sav", verbose = FALSE))
   
   expect_is(els, "edsurvey.data.frame")
-  expect_equal(dim(els), c(16197, 9012))
+  expect_equal(dim(els), c(16197, 9013))
   
   expect_silent(elsSchl <<- readELS(file.path(edsurveyHome, "ELS", "2002"), filename = "els_02_12_byf1sch_v1_0.sav", wgtFilename = NULL, verbose = FALSE))
   expect_is(elsSchl, "edsurvey.data.frame")
-  expect_equal(dim(elsSchl), c(1954, 925)) #21409 obs::18928 cols
+  expect_equal(dim(elsSchl), c(1954, 926)) #21409 obs::18928 cols
 })
 
 context("ELS getData")
 test_that("ELS getData",{
-  dat1 <- getData(els, c("stu_id", "bysex", "byrace"))
+  withr::with_options(list(digits = 4), dat1 <- getData(els, c("stu_id", "bysex", "byrace"))) #digits=4 impacts rounding in summary call
   expect_equal(dim(dat1), c(15244, 3))
-  withr::with_options(list(digits=7), co <- capture.output(summary(dat1)))
+  withr::with_options(list(digits = 4), co <- capture.output(summary(dat1)))
   expect_equal(co, dat1Summary.Ref)
   
   #test ELS School variables
-  dat2 <- getData(elsSchl, c("sch_id", "byregion", "byurban"), omittedLevels = FALSE)
+  withr::with_options(list(digits = 4), dat2 <- getData(elsSchl, c("sch_id", "byregion", "byurban"), omittedLevels = FALSE)) #digits=4 impacts rounding in summary call
   expect_equal(dim(dat2), c(1954, 3))
-  withr::with_options(list(digits=7), co <- capture.output(summary(dat2)))
+  withr::with_options(list(digits = 4), co <- capture.output(summary(dat2)))
   expect_equal(co, dat2Summary.Ref)
   
   #test with some continuous variables that have omittedLevels
-  dat3 <- getData(els, c("stu_id", "f1ses1", "f1ses1qu", "f1ses2", "f1ses2qu"))
+  withr::with_options(list(digits = 7), dat3 <- getData(els, c("stu_id", "f1ses1", "f1ses1qu", "f1ses2", "f1ses2qu"))) #digits=4 impacts rounding in summary call
   expect_equal(dim(dat3), c(16160, 5))
-  withr::with_options(list(digits=7), co <- capture.output(summary(dat3)))
+  withr::with_options(list(digits = 7), co <- capture.output(summary(dat3)))
   expect_equal(co, dat3Summary.Ref)
 })
 
